---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------

set serveroutput on size 1000000
-- This script is a part of 2.2.1.0.1 - 2.2.1.0-TIV-PROSPECT-3COMTPT-IF0001
--
-- 2.2.1.0.1 will check the definitions of 3 entity tables in the 3Com TippingPoint hierarchy
-- to make sure that the column defined for storing the Tipping Point ID is at least 30
-- characters in size.
--
-- If the columns are already configured as the minimum size or larger, then no changes will
-- be made, this is to avoid errors trying to resize the columns

DECLARE
  vCount       NUMBER;
  vSize        NUMBER;
BEGIN
  -- ENTITY: Interface Table:TPT_ENT_IF Column: INTERFACES_ID
  SELECT count(table_name) INTO vCount FROM user_tables WHERE table_name = 'TPT_ENT_IF';
  IF (vCount > 0) THEN
    -- Check existing size to make sure it is not changed adversely
    SELECT data_length INTO vSize FROM user_tab_columns
    WHERE table_name = 'TPT_ENT_IF'
    AND column_name = 'INTERFACES_ID';

    -- if the length is appropriate, run the SQL and recompile the trigger which is made invalid.
    IF (vSize < 30) THEN
      run_sql(' ALTER TABLE tpt_ent_if MODIFY (interfaces_id VARCHAR2(30))');
      run_sql(' ALTER TRIGGER tpt_ent_if_biu COMPILE');
    ELSE
      dbms_output.put_line('OK: TPT_ENT_IF - INTERFACES_ID is already at min required size');
    END IF;
  ELSE
    dbms_output.put_line('Error: Unable to locate table TPT_ENT_IF in user_tables');
  END IF;

  -- ENTITY: NPStatsTiers.xml Table:TPT_ENT_NPSTATSTIERS Column: NPSTATS_ID
  SELECT count(table_name) INTO vCount FROM user_tables WHERE table_name = 'TPT_ENT_NPSTATSTIERS';
  IF (vCount > 0) THEN
    -- Check existing size to make sure it is not changed adversely
    SELECT data_length INTO vSize FROM user_tab_columns
    WHERE table_name = 'TPT_ENT_NPSTATSTIERS'
    AND column_name = 'NPSTATS_ID';

    -- if the length is appropriate, run the SQL and recompile the trigger which is made invalid.
    IF (vSize < 30) THEN
      run_sql(' ALTER TABLE tpt_ent_npstatstiers MODIFY (npstats_id VARCHAR2(30))');
      run_sql(' ALTER TRIGGER tpt_ent_npstatstiers_biu compile');
    ELSE
      dbms_output.put_line('OK: TPT_ENT_NPSTATSTIERS - NPSTATS_ID is already at min required size');
    END IF;
  ELSE
    dbms_output.put_line('Error: Unable to locate table TPT_ENT_NPSTATSTIERS in user_tables');
  END IF;

END;
/
